@@ -4,6 +4,7 @@ import inspect
 from types import MethodType
 from typing import TypeVar, Dict
 
+from django.db.models.expressions import CombinedExpression
 from django.forms.widgets import Select
 
 from .helpers import get_url, render_replace, DUMMY_ID
@@ -78,7 +79,7 @@ class ColumnBase:
         self.column_name, options = self.extract_options(kwargs.get('column_name', ''))
         self.options: Dict[KT, VT] = options
         self.model_path = kwargs.pop('model_path', None)
-        if not self.model_path is not None:
+        if self.model_path is None:
             self.model_path = self.get_model_path(self.column_name)
             if '/' in self.model_path:
                 self.model_path = self.model_path[self.model_path.find('/') + 1:]
@@ -158,6 +159,16 @@ class ColumnBase:
     def annotations_value(self, value):
         self._annotations_value = self._set_annotations(value)
 
+    def _combined_expression_annotations(self, expression):
+        if isinstance(expression.lhs, CombinedExpression):
+            self._combined_expression_annotations(expression.lhs)
+        else:
+            expression.lhs.name = self.model_path + expression.lhs.name
+        if isinstance(expression.rhs, CombinedExpression):
+            self._combined_expression_annotations(expression.rhs)
+        else:
+            expression.rhs.name = self.model_path + expression.rhs.name
+
     def _set_annotations(self, value):
         annotations = copy.deepcopy(value)
         if self.model_path:
@@ -165,7 +176,10 @@ class ColumnBase:
             for k in annotations:
                 new_annotations[self.model_path + k] = annotations[k]
                 for e in new_annotations[self.model_path + k].source_expressions:
-                    e.name = self.model_path + e.name
+                    if isinstance(e, CombinedExpression):
+                        self._combined_expression_annotations(e)
+                    else:
+                        e.name = self.model_path + e.name
             annotations = new_annotations
         for f in annotations:
             if self.field is None:
@@ -355,11 +369,14 @@ class ColumnLink(ColumnBase):
     def url(self, url_name):
         self._url = get_url(url_name)
 
-    def __init__(self, *, url_name, link_ref_column='id', link_html=None, link_css='', var='%1%', **kwargs):
+    def __init__(self, *, url_name, link_ref_column=None, link_html=None, link_css='', var='%1%', **kwargs):
         if not self.initialise(locals()):
             return
         super().__init__(**self.kwargs)
-        link_ref_column = self.model_path + link_ref_column
+        if link_ref_column:
+            link_ref_column = self.model_path + link_ref_column
+        else:
+            link_ref_column = self.column_name
         self.url = url_name
 
         if not link_html:
@@ -367,18 +384,27 @@ class ColumnLink(ColumnBase):
 
         if not link_css:
             link_css = self.base_link_css
+
+        self.var = var
+        self.link_ref_column = link_ref_column
+        self.setup_link(link_css, link_html)
+
+    def setup_link(self, link_css, link_html):
         link_css = f' class="{link_css}"' if link_css else ''
         link = f'<a{link_css} href="{self.url}">{{}}</a>'
         if isinstance(self.field, (list, tuple)):
             self.options['render'] = [
-                render_replace(column=self.column_name + ':0', html=link.format('%1%'), var='999999'),
+                render_replace(column=self.column_name + ':0', html=link.format(link_html), var='999999'),
                 render_replace(column=self.column_name + ':1'),
             ]
-        elif var not in link_html:
-            self.options['render'] = [render_replace(column=link_ref_column, html=link.format(link_html), var='999999')]
+        elif self.var not in link_html:
+            self.options['render'] = [render_replace(column=self.link_ref_column,
+                                                     html=link.format(link_html), var='999999')]
         else:
-            self.options['render'] = [render_replace(column=self.column_name, html=link.format(link_html), var=var),
-                                      render_replace(column=link_ref_column, var='999999')]
+            self.options['render'] = [render_replace(column=self.column_name,
+                                                     html=link.format(link_html),
+                                                     var=self.var),
+                                      render_replace(column=self.link_ref_column, var='999999')]
 
 
 class ManyToManyColumn(DatatableColumn):
@@ -504,7 +530,7 @@ class CurrencyColumn(ColumnBase):
 
 class BooleanColumn(DatatableColumn):
 
-    def __init__(self, *,  choices=None, **kwargs):
+    def __init__(self, *,  choices=None, replace=None, **kwargs):
         if not self.initialise(locals()):
             return
         super().__init__(**kwargs)
@@ -513,6 +539,11 @@ class BooleanColumn(DatatableColumn):
         else:
             self.choices = ['true', 'false', None]
 
+        if replace:
+            self.options['render'] = [{'function': 'ReplaceLookup', 'html': '%1%', 'var': '%1%'}]
+            self.options['lookup'] = [(self.choices[c], r) for c, r in enumerate(replace)]
+            self.options['no_col_search'] = True
+
     def row_result(self, data, _page_data):
         try:
             if data[self.field] is None:
@@ -573,3 +604,27 @@ class MenuColumn(NoHeadingColumn):
         menu_rendered = menu.render().replace(str(DUMMY_ID), '%1%')
         kwargs['render'] = [render_replace(html=menu_rendered, column=kwargs['column_name'])]
         super().__init__(**kwargs)
+
+
+class SelectColumn(DatatableColumn):
+
+    def __init__(self, field='id', **kwargs):
+        def button(title, font_awesome, data_command=None):
+            return (
+                f'''<button class="table-select" onclick="django_datatables.column_select(this)" title="{title}"'''
+                f'''{(f' data-command="' + data_command + '"') if data_command else ''}>'''
+                f'''<i class="{font_awesome}"></i></button>'''
+            )
+        kwargs['title'] = '<div class="d-flex"><div class="m-auto">{}{}</div></div>'.format(
+            button('Select all', 'fas fa-check-square'), button('Unselect all', 'far fa-square', 'clear')
+        )
+        kwargs['render'] = [{'function': 'Replace',
+                             'html': '<input class="col-sel" type="checkbox" name="%1%" title="Select">',
+                             'var': '%1%'}]
+        kwargs['no_col_search'] = True
+        kwargs['column_defs'] = {'orderable': False, 'className': 'dt-center'}
+        super().__init__(field=field, **kwargs)
+
+    def col_setup(self):
+        # Required so select all, works on pages not viewed
+        self.table.table_options['deferRender'] = False
\ No newline at end of file
